// ----------------------------------------------------------------------------
// Copyright (C) 2014
//              David Freese, W1HKJ
//
// This file is part of flrig.
//
// flrig is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// flrig is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef _IC728_H
#define _IC728_H

#include "ICbase.h"

class RIG_IC728 : public RIG_ICOM {
public:
	RIG_IC728();
	~RIG_IC728(){}

	bool check();

	unsigned long int get_vfoA();
	void set_vfoA(unsigned long int);

	int  adjust_bandwidth(int m) { return 1; }

};

#endif
